# Unit 2: Biology

## Cellular Biology
A person contains roughly 100 trillion cells
- Cells are roughly 20 `μm` (micrometre, 10<sup>-6</sup> m), around 250 cells / cm

## Cell Theory
1. All living things are composed of cells 
2. Cells are the basic units of living organisms
3. All cells came from pre-existing cells

## Eukaryotic versus Prokaryotic Cells
`Prokaryotic cell`: Meaning before/lacking nucleus

`Eukaryotic cell`: Means complete nucleus

|Factors|Prokaryotic|Eukaryotic|
|:-----------|:----------|:---------|
|DNA|In nucleoid region|Usually in membrane-bound nucleus|
|Size|Usually smaller|Usually larger|
|Organelles|Not membrane-bound, smaller|Membrane-bound, more complex|
|Organization|Usually singlecelled|Often form multicellular organisms|
|Metabolism|May not need oxygen|Usually need oxygen|

## Cellular Organelles

### Business Analogy

| In a business | In a cell | 
| ------------- | --------- |
| Building      | Cytoplasm & Cytoskeleton |
| Department Head | Organelles |
| Boss          | DNA |
| Workers       | Ribosomes & Enzymes |
| Waste management | Lysosomes |
| Storage       | Vacuoles | 
| Powerhouse    | Chloroplasts & Mitochondria |
| Security gate | Cell membrane controls entrance and exit from the cell |
| Transportation Department | IMPORT: Cell membranes and vesicles, INTERNAL: Endoplasmic reticulum & vesicles, EXPORT: Golgi apparatus, vesicles, and cell membrane |


### Cell Membrane
- Controls what substances enter/leave the cell selectively via various receptors/osmosis
    - Allows nutrients to enter
    - Allows waste products to leave
- Surrounds and holds other organelles in cell
- Interact with outside chemicals (e.g., hormones)

### Nucleus
- Holds deoxyribonucleic acid (DNA) in form of `chromatin`
    - DNA is a double helix containing genes
        - `Genes` are a full set of instructions in DNA to make either RNA or a protein
    - `Chromatin` is DNA wrapped tightly in protein
- `Chromosomes` are even more tightly wrapped chromatin used in cell division only
- Surrounded by a double membrane
- Substances enter and exit the nucleus via nuclear pores
- Messenger RNA (mRNA) is encoded from DNA and sent to `ribosomes` to produce proteins
- Humans have ~2 m of genes per cell per nucleus tightly wrapped


### Nucleolus
 - Dense region of DNA located in the nucleus
 - This area of DNA is specially for ribosomal DNA (rDNA), or DNA used to make ribosomes
 - Produce "large" and "small" subunits of ribosomes, which either form complete ribosomes in cytosol or mix with endoplasmic reticulum, forming rough endoplasmic reticulum (RER)

### Cytoplasm & Cytosol
 - `Cytosol` is the fluid cells contain
 - **All organelles** are suspended in `cytosol`
 - `Cytoplasm` is the `cytosol` along with everything in a cell, excluding the nucleus

## Endoplasmic Reticulum
- The endoplasmic reticulum is a network of tubules and flattened sacs with a "rough" appearance because of the presence of `ribosomes` on the surface
- Network of tubules and flattened sacs
- **Transports** proteins via cytoskeleton in vesicles

## Specific to Rough ER
- Appears "rough" due to the `ribosomes` attached to its outer surface
- Located directly adjacent and attached to nucleus
- Located next to `Golgi apparatus`
- `Ribosomes` in rough ER **synthesize proteins**
    - Transports synthesized proteins to `Golgi apparatus` for packaging and distribution
    - About half the cell's proteins are produced here
- Folds, fixes and **modifies both newly-created and pre-existing proteins** somewhat like **proof-reading**

## Specific to Smooth ER
- Does not synthesize proteins
- Appears "smooth" due to lack of `ribosomes`
- Located directly adjacent and attached to nucleus
- Synthesizes lipids (fats, e.g., cholesterol)
- Metabolises carbohydrates

## Golgi Apparatus
- Also known as Golgi body, Golgi complex, etc.
- **Receives, modifies and transports** proteins that were produced by the rough ER
- **Packages** proteins into `vesicles` and sends them `cell membrane` for export

## Lysosome
- Spherical vesicle that containing `enzymes`
- **Digests and kills** foreign matter which is then excreted
     - E.g., white blood cells use lysosomes to kill bacteria then spit it out
- **Digests and breaks down** old and unused material/non-functional organelles as needed
- If lysosome ruptures everything dies, hence they are known as "suicude sacs"

## Mitochondria
 - **Singular form is "mitochondrion"**
 - Contains an inner and outer membrane
 - Processes glucose + oxygen gas to form carbon dioxide + adenosine triphosphate (ATP)
    - ATP allows proteins to do things (e.g., spend 1 ATP break 1 molecule)
    - ATP cannot be stored

## Cytoskeleton
- Made of protein filaments
- Maintains and changes cell structure, much like a human skeleton + muscular system
    - Moves cells
    - Modifies and adjusts cell structure as needed
- Chemicals can travel along cytoskeleton, e.g., organelles, vesicles, etc.

## Organelles specific to animal cells

### Centrioles and centrosomes
 - Made of same protein as cytoskeleton
 - A centrosome is a pair of centrioles
 - Important to cell division in animal cells
 - Create cilia and flagella (e.g., small hair-like things that swipe dirt out of lungs and tails of sperm, respectively)

### Lysosomes

## Organelles specific to plant cells

### Cell wall
- Provides structure and prevents cell rupture
- Can be tough, flexible, and/or rigid
- Made of cellulose (type of sugar)
- Also present in most bacteria, fungi, and protists

### Chloroplast
- The `solar panel` of the plant cell
- Conducts photosynthesis
- All chlorophyll is located in chloroplasts
- Looks green

### Central Vacuole
- Extremely large, may take up to 90% of volume in cell
- Contains water
- Maintains `turgor` pressure against cell wall (pushes against cell wall in all directions)
- Maintains cell shape and resistance
    - Plant cells that lack turgor pressure (e.g., celery left in fridge) become flaccid

## Cell division
### Purpose
#### Growth
 - Cells have maximum size before transportation of substances within cell becomes inefficient
 - Cells transport chemicals (e.g., nutrients) via `diffusion`

#### Reproduction
 - Single-cellular organisms reproduce via division asexually
 - Multicellular organisms reproduce via combining two germ cells ("sex cells") that contain half the DNA each of two organisms
    - This is sexual

#### Repair
 - Cells naturally die and need to be replaced
    - e.g., red blood cells, hair cells, skin, injuries

### Cell cycle
 - Interphase
    - G1
    - S
    - G2
 - Mitosis
    - Occurs only in eukaryotic cells
    - Prophase
    - Prometaphase
    - Metaphase
    - Anaphase
    - Telophase
 - Cytokinesis
 - G0
    - Cell no longer divides
    - Outisde of cell cycle